# vim: sw=4:ts=4:et
#
# Copyright (c) 2013 Red Hat, Inc.

# This program and entire repository is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the License,
# or any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

%define selinux_variants targeted

%if 0%{?rhel} == 7
# absolute minimum versions for RHEL 7.1
%define selinux_policy_ver 3.13.1-7
%else
# absolute minimum versions for RHEL 6.6
%define selinux_policy_ver 3.7.19-271
%endif
%define selinux_policycoreutils_ver 1.33.12-1

%define moduletype apps
%define modulename foreman

# set and uncomment all three to set alpha tag
#global alphatag RC2
#global dotalphatag .%{alphatag}
#global dashalphatag -%{alphatag}

Name:           %{modulename}-selinux
Version:        1.7.2.14
Release:        1%{?dotalphatag}%{?dist}
Summary:        SELinux policy module for Foreman

Group:          System Environment/Base
License:        GPLv3+
URL:            http://www.theforeman.org
Source0:        http://downloads.theforeman.org/%{name}/%{name}-%{version}%{?dashalphatag}.tar.gz

BuildRequires:  checkpolicy, selinux-policy-devel, hardlink
BuildRequires:  policycoreutils >= %{selinux_policycoreutils_ver}
BuildRequires:  /usr/bin/pod2man
BuildArch:      noarch

Requires:           selinux-policy >= %{selinux_policy_ver}
Requires(post):     /usr/sbin/semodule, /sbin/restorecon, /usr/sbin/setsebool, /usr/sbin/selinuxenabled, /usr/sbin/semanage
Requires(post):     policycoreutils-python
Requires(post):     selinux-policy-targeted
Requires(postun):   /usr/sbin/semodule, /sbin/restorecon

%description
SELinux policy module for Foreman

%prep
%setup -q -n %{name}-%{version}%{?dashalphatag}

cat downstream.te.in >> foreman.te

%build
# create selinux-friendly version from VR and replace it inplace
perl -i -pe 'BEGIN { $VER = join ".", grep /^\d+$/, split /\./, "%{version}.%{release}"; } s!\@\@VERSION\@\@!$VER!g;' %{modulename}.te

# determine distribution name and version
%if 0%{?rhel} >= 6
    distver=rhel%{rhel}
%endif
%if 0%{?fedora} >= 18
    distver=fedora%{fedora}
%endif

# build policy
for selinuxvariant in %{selinux_variants}
do
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile DISTRO=${distver}
    bzip2 -9 %{modulename}.pp
    mv %{modulename}.pp.bz2 %{modulename}.ppbz2.${selinuxvariant}
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean DISTRO=${distver}
done

# build man pages
/usr/bin/pod2man --name=foreman-selinux-enable -c "Foreman Reference" --section=8 --release=%{version} foreman-selinux-enable.pod foreman-selinux-enable.man8
/usr/bin/pod2man --name=foreman-selinux-disable -c "Foreman Reference" --section=8 --release=%{version} foreman-selinux-disable.pod foreman-selinux-disable.man8
/usr/bin/pod2man --name=foreman-selinux-relabel -c "Foreman Reference" --section=8 --release=%{version} foreman-selinux-relabel.pod foreman-selinux-relabel.man8

%install
# install policy modules
for selinuxvariant in %{selinux_variants}
  do
    install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    install -p -m 644 %{modulename}.ppbz2.${selinuxvariant} \
        %{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp.bz2
  done

# install interfaces
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 %{modulename}.if %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if

# hardlink identical policy module packages together
/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux

# install enable/relabel scripts which will be called in %posttrans
install -d %{buildroot}%{_sbindir}
install -p -m 755 %{name}-enable %{buildroot}%{_sbindir}/%{name}-enable
install -p -m 755 %{name}-disable %{buildroot}%{_sbindir}/%{name}-disable
install -p -m 755 %{name}-relabel %{buildroot}%{_sbindir}/%{name}-relabel

# install man pages
install -d -m 0755 %{buildroot}%{_mandir}/man8
install -m 0644 foreman-selinux-enable.man8 %{buildroot}%{_mandir}/man8/foreman-selinux-enable.8
install -m 0644 foreman-selinux-disable.man8 %{buildroot}%{_mandir}/man8/foreman-selinux-disable.8
install -m 0644 foreman-selinux-relabel.man8 %{buildroot}%{_mandir}/man8/foreman-selinux-relabel.8

%post
if /usr/sbin/selinuxenabled; then
    # install and upgrade
    %{_sbindir}/%{name}-enable
fi

%posttrans
if /usr/sbin/selinuxenabled; then
    # install and upgrade
    %{_sbindir}/%{name}-relabel
fi

%preun
if /usr/sbin/selinuxenabled; then
    # uninstall only
    if [ $1 -eq 0 ]; then
        %{_sbindir}/%{name}-disable
    fi
    # upgrade and uninstall
    %{_sbindir}/%{name}-relabel
fi

%files
%doc Contributors CHANGELOG LICENSE %{modulename}.fc %{modulename}.if %{modulename}.te %{modulename}.sh
%attr(0600,root,root) %{_datadir}/selinux/*/%{modulename}.pp.bz2
%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if
%{_mandir}/man8/*
%attr(0755,root,root) %{_sbindir}/%{name}-enable
%attr(0755,root,root) %{_sbindir}/%{name}-disable
%attr(0755,root,root) %{_sbindir}/%{name}-relabel

%changelog
* Mon Oct 05 2015 Mike McCune <mmccune@redhat.com> 1.7.2.14-1
- 1136991 - improved building experience (lzap+git@redhat.com)
- 1136991 - OpenStack support (lzap+git@redhat.com)
- Fixes #1243311 - updated minimum requirements for RHEL 6.6
  (lzap+git@redhat.com)

* Tue Mar 24 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.13-1
- remove necessary line deleted by PR (jmontleo@redhat.com)
- 1164164 - added 8080 to allowed http cache ports (lzap+git@redhat.com)

* Fri Mar 20 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.12-1
- removed unused apache_template macro and types (jmontleo@redhat.com)

* Fri Mar 20 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.11-1
- 1198307 - remove unused httpd_foreman_script_t types (lzap+git@redhat.com)

* Thu Mar 19 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.10-1
- workaround BZ1198307 (jmontleo@redhat.com)
- 1202994 - foreman can connect to remote SMTP (lzap+git@redhat.com)

* Tue Mar 03 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.9-1
- 1193701 - block installation of selinux on RHEL 7.0 (lzap+git@redhat.com)
- Updated Rakefile to test downstream.te.in (lzap+git@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.8-1
- correct certs policy for RHEL 6 (jmontleo@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.7-1
- 1183127 - docker port and unix socket allowed (lzap+git@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.6-1
- 1185401 - allowed celery to manage cert_t files (lzap+git@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.5-1
- fix celery policy for RHEL 6 (jmontleo@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.4-1
- 1164164 - connections to http proxy allowed (lzap+git@redhat.com)

* Thu Feb 05 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.3-1
- 1185401 - allowed celery to read cert_t (lzap+git@redhat.com)

* Tue Jan 27 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.2-1
- fix type in downstream policy merge request (jmontleo@redhat.com)

* Tue Jan 27 2015 Jason Montleon <jmontleo@redhat.com> 1.7.2.1-1
- Merge branch 'celery-bind-1172842' of
  https://gitlab.sat.lab.tlv.redhat.com/lzapleta/foreman-selinux into lzapleta
  /foreman-selinux-celery-bind-1172842 (jmontleo@redhat.com)
- update to 1.7.2 (jmontleo@redhat.com)
- Merge remote-tracking branch 'upstream/1.7-stable' into SATELLITE-6.1.0
  (jmontleo@redhat.com)
- Release 1.7.2 (dcleal@redhat.com)
- 1172842 - allowed pulp/celery to bind 5000 (lzap+git@redhat.com)
- RHBZ#1185801 - added AMQP port connect for passenger (lzap+git@redhat.com)

* Wed Dec 17 2014 Jason Montleon <jmontleo@redhat.com> 1.7.1.1-1
- update version to 1.7.1 (jmontleo@redhat.com)

* Wed Dec 17 2014 Jason Montleon <jmontleo@redhat.com> 1.7.0.4-1
- Merge tag '1.7.1' into SATELLITE-6.1.0 (jmontleo@redhat.com)
- Release 1.7.1 (dcleal@redhat.com)
- Fixes #8241 - added rules for local sockets libvirt connections
  (lzap+git@redhat.com)
- Fixes #8030 - allow UDP port binds for ruby net package (lzap+git@redhat.com)

* Wed Dec 17 2014 Jason Montleon <jmontleo@redhat.com> 1.7.0.3-1
- 1172842 - added 5000 tcp bind and backported downstream patches
  (lzap+git@redhat.com)

* Fri Dec 12 2014 Lukas Zapletal <lzap+rpm@redhat.com> 1.7.0.2-2
- backported downstream rules from Satellite 6.0
- 1172842 - added rule for httpd_t 5000 tcp bind

* Fri Dec 05 2014 Jason Montleon <jmontleo@redhat.com> 1.7.0.2-1
- fix source package format in rpm spec (jmontleo@redhat.com)

* Fri Dec 05 2014 Jason Montleon <jmontleo@redhat.com> 1.7.0.1-1
- update foreman-selinux to 1.7.0.0 (jmontleo@redhat.com)
- Release 1.7.0 (dcleal@redhat.com)
- Release 1.7.0-RC2 (dcleal@redhat.com)
- Release 1.7.0-RC1 (dcleal@redhat.com)
- Fixes #7932 - added LDAP support for passenger (lzap+git@redhat.com)
- Refs #7719 - added websockify rules for VNC console (lzap+git@redhat.com)
- Fixes #7719 - added ssh rules for libvirt CR (lzap+git@redhat.com)
- refs #7388 - make foreman-selinux-enable upgrade-safe (dcleal@redhat.com)
- fixes #7729 - allow websockify to read certs (stbenjam@redhat.com)
- Fixes #7346 - Added OpenStack port 5000 via boolean (lzap+git@redhat.com)
- Refs #7178 - removed passenger_t execmem rule (lzap+git@redhat.com)
- Fixes #7198 - allowed httpd_t to read/write to passenger socket
  (lzap+git@redhat.com)

* Tue Dec 02 2014 Dominic Cleal <dcleal@redhat.com> 1.7.0-1
- Release 1.7.0

* Tue Nov 25 2014 Dominic Cleal <dcleal@redhat.com> 1.7.0-0.2.RC2
- Release 1.7.0-RC2

* Tue Nov 11 2014 Dominic Cleal <dcleal@redhat.com> 1.7.0-0.1.RC1
- Release 1.7.0-RC1

* Mon Aug 11 2014 Dominic Cleal <dcleal@redhat.com> - 1.7.0-0.develop
- Bump version to 1.7-develop

* Wed Apr 16 2014 Dominic Cleal <dcleal@redhat.com> - 1.6.0-0.develop
- Bump to version 1.6-develop

* Thu Jan 16 2014 Dominic Cleal <dcleal@redhat.com> - 1.5.0-0.develop
- Bump to version 1.5-develop

* Thu Nov 21 2013 Dominic Cleal <dcleal@redhat.com> - 1.4.0-0.develop
- Bump and change versioning scheme (#3712)

* Thu Sep 05 2013 Lukas Zapletal <lzap+rpm[@]redhat.com> - 1.3.9999-1
- Bump to version 1.3-develop

* Mon Jun 03 2013 Lukas Zapletal <lzap+rpm[@]redhat.com> - 1.2.9999-1
- Brand new SPEC adopted from Katello project
- Changes to the policy to get SCL working

* Tue Feb 26 2013 Sam Kottler <shk@redhat.com> 1.1.1-1
- Initial version
